==> ldcoolp-figshare-0.3.1.tar.gz: ldcoolp-figshare-0.3.1/CHANGELOG.md <==
# Changelog

## [v0.3.1](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.3.1) (2021-07-01)

**Merged pull requests:**
 - Org rename [#25](https://github.com/UAL-RE/ldcoolp-figshare/pull/25)


## [v0.3.0](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.3.0) (2021-06-08)

**Implemented enhancements:**
 -  Update use of redata.commons to include process option [#24](https://github.com/UAL-RE/ldcoolp-figshare/pull/24)

**Closed issues:**
 -  Update use of redata.commons to include process option [#23](https://github.com/UAL-RE/ldcoolp-figshare/issues/23)


## [v0.2.2](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.2.2) (2021-06-03)

**Implemented enhancements:**
 - For get_curation_list method, allow for pending selection [#21](https://github.com/UAL-RE/ldcoolp-figshare/pull/21)
 
**Fixed bugs:**
 - Remove GitHub badges from RTDs [#20](https://github.com/UAL-RE/ldcoolp-figshare/issues/20)

**Closed issues:**
 - For get_curation_list method, allow for pending selection [#19](https://github.com/UAL-RE/ldcoolp-figshare/issues/19)

**Merged pull requests:**
 - Remove GitHub badges from RTDs [#22](https://github.com/UAL-RE/ldcoolp-figshare/pull/22)


## [v0.2.0](https://github.com/UAL-RE/ldcoolp-figshare/tree/HEAD) (2021-05-24)

**Implemented enhancements:**
 - Prepare code for PyPI packaging; Add CHANGELOG [#15](https://github.com/UAL-RE/ldcoolp-figshare/pull/15)

**Closed issues:**
 - Update README.md with RTDs information and links [#12](https://github.com/UAL-RE/ldcoolp-figshare/issues/12)
 - Prepare code for PyPI packaging [#4](https://github.com/UAL-RE/ldcoolp-figshare/issues/4)
 - Add CHANGELOG [#14](https://github.com/UAL-RE/ldcoolp-figshare/issues/14)

**Merged pull requests:**
 - Update README.md with RTDs information and links [#13](https://github.com/UAL-RE/ldcoolp-figshare/pull/13)


## [v0.1.0](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.1.0) (2021-05-20)

**Implemented enhancements:**
 - Add Sphinx documentation and publish to ReadTheDocs [#11](https://github.com/UAL-RE/ldcoolp-figshare/pull/11)

**Closed issues:**
 - Add Sphinx documentation and publish to ReadTheDocs [#10](https://github.com/UAL-RE/ldcoolp-figshare/issues/10)


## [v0.0.3](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.0.3) (2021-05-18)

**Closed issues:**
 - Refactor FigshareInstituteAdmin for general use [#7](https://github.com/UAL-RE/ldcoolp-figshare/issues/7)
 - Add GitHub action to create releases with v* tags [#9](https://github.com/UAL-RE/ldcoolp-figshare/issues/9)

**Merged pull requests:**
 - Refactor FigshareInstituteAdmin for general use [#8](https://github.com/UAL-RE/ldcoolp-figshare/pull/8)


## [v0.0.2](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.0.2) (2021-05-18)

**Implemented enhancements:**
 - Include issue_request from redata-commons [#6](https://github.com/UAL-RE/ldcoolp-figshare/pull/6)

**Closed issues:**
 - Chore: Add README.md, LICENSE, and .gitignore files [#3](https://github.com/UAL-RE/ldcoolp-figshare/issues/3)
 - Include issue_request from redata-commons [#5](https://github.com/UAL-RE/ldcoolp-figshare/issues/5)


## [v0.0.1](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.0.1) (2021-05-14)

**Closed issues:**
 - Reorganize codebase for easier packaging [#1](https://github.com/UAL-RE/ldcoolp-figshare/issues/1)

**Merged pull requests:**
 - Reorganize codebase for easier packaging [#2](https://github.com/UAL-RE/ldcoolp-figshare/pull/2)


<!-- TEMPLATE
## [vXX.YY.ZZ](https://github.com/UAL-RE/ldcoolp-figshare/tree/vXX.YY.ZZ) (YYYY-MM-DD)

**Implemented enhancements:**
 - `______` [#XX](https://github.com/UAL-RE/ldcoolp-figshare/pull/XX)

**Fixed bugs:**
 - `______` [#XX](https://github.com/UAL-RE/ldcoolp-figshare/issues/XX)

**Closed issues:**
 - `______` [#XX](https://github.com/UAL-RE/ldcoolp-figshare/issues/XX)

**Merged pull requests:**
 - `______` [#XX](https://github.com/UAL-RE/ldcoolp-figshare/pull/XX)

-->

==> ldcoolp-figshare-0.3.2.tar.gz: ldcoolp-figshare-0.3.2/CHANGELOG.md <==
# Changelog

## [v0.3.2](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.3.2) (2021-07-07)

**Implemented enhancements:**
 - Add method to retrieve ORCID and Figshare account ID for users
   [#27](https://github.com/UAL-RE/ldcoolp-figshare/pull/27)

**Closed issues:**
 - Add method to retrieve ORCID and Figshare account ID for users
   [#26](https://github.com/UAL-RE/ldcoolp-figshare/issues/26)


## [v0.3.1](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.3.1) (2021-07-01)

**Merged pull requests:**
 - Org rename [#25](https://github.com/UAL-RE/ldcoolp-figshare/pull/25)


## [v0.3.0](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.3.0) (2021-06-08)

**Implemented enhancements:**
 -  Update use of redata.commons to include process option [#24](https://github.com/UAL-RE/ldcoolp-figshare/pull/24)

**Closed issues:**
 -  Update use of redata.commons to include process option [#23](https://github.com/UAL-RE/ldcoolp-figshare/issues/23)


## [v0.2.2](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.2.2) (2021-06-03)

**Implemented enhancements:**
 - For get_curation_list method, allow for pending selection [#21](https://github.com/UAL-RE/ldcoolp-figshare/pull/21)
 
**Fixed bugs:**
 - Remove GitHub badges from RTDs [#20](https://github.com/UAL-RE/ldcoolp-figshare/issues/20)

**Closed issues:**
 - For get_curation_list method, allow for pending selection [#19](https://github.com/UAL-RE/ldcoolp-figshare/issues/19)

**Merged pull requests:**
 - Remove GitHub badges from RTDs [#22](https://github.com/UAL-RE/ldcoolp-figshare/pull/22)


## [v0.2.0](https://github.com/UAL-RE/ldcoolp-figshare/tree/HEAD) (2021-05-24)

**Implemented enhancements:**
 - Prepare code for PyPI packaging; Add CHANGELOG [#15](https://github.com/UAL-RE/ldcoolp-figshare/pull/15)

**Closed issues:**
 - Update README.md with RTDs information and links [#12](https://github.com/UAL-RE/ldcoolp-figshare/issues/12)
 - Prepare code for PyPI packaging [#4](https://github.com/UAL-RE/ldcoolp-figshare/issues/4)
 - Add CHANGELOG [#14](https://github.com/UAL-RE/ldcoolp-figshare/issues/14)

**Merged pull requests:**
 - Update README.md with RTDs information and links [#13](https://github.com/UAL-RE/ldcoolp-figshare/pull/13)


## [v0.1.0](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.1.0) (2021-05-20)

**Implemented enhancements:**
 - Add Sphinx documentation and publish to ReadTheDocs [#11](https://github.com/UAL-RE/ldcoolp-figshare/pull/11)

**Closed issues:**
 - Add Sphinx documentation and publish to ReadTheDocs [#10](https://github.com/UAL-RE/ldcoolp-figshare/issues/10)


## [v0.0.3](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.0.3) (2021-05-18)

**Closed issues:**
 - Refactor FigshareInstituteAdmin for general use [#7](https://github.com/UAL-RE/ldcoolp-figshare/issues/7)
 - Add GitHub action to create releases with v* tags [#9](https://github.com/UAL-RE/ldcoolp-figshare/issues/9)

**Merged pull requests:**
 - Refactor FigshareInstituteAdmin for general use [#8](https://github.com/UAL-RE/ldcoolp-figshare/pull/8)


## [v0.0.2](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.0.2) (2021-05-18)

**Implemented enhancements:**
 - Include issue_request from redata-commons [#6](https://github.com/UAL-RE/ldcoolp-figshare/pull/6)

**Closed issues:**
 - Chore: Add README.md, LICENSE, and .gitignore files [#3](https://github.com/UAL-RE/ldcoolp-figshare/issues/3)
 - Include issue_request from redata-commons [#5](https://github.com/UAL-RE/ldcoolp-figshare/issues/5)


## [v0.0.1](https://github.com/UAL-RE/ldcoolp-figshare/tree/v0.0.1) (2021-05-14)

**Closed issues:**
 - Reorganize codebase for easier packaging [#1](https://github.com/UAL-RE/ldcoolp-figshare/issues/1)

**Merged pull requests:**
 - Reorganize codebase for easier packaging [#2](https://github.com/UAL-RE/ldcoolp-figshare/pull/2)


<!-- TEMPLATE
## [vXX.YY.ZZ](https://github.com/UAL-RE/ldcoolp-figshare/tree/vXX.YY.ZZ) (YYYY-MM-DD)

**Implemented enhancements:**
 - `______` [#XX](https://github.com/UAL-RE/ldcoolp-figshare/pull/XX)

**Fixed bugs:**
 - `______` [#XX](https://github.com/UAL-RE/ldcoolp-figshare/issues/XX)

**Closed issues:**
 - `______` [#XX](https://github.com/UAL-RE/ldcoolp-figshare/issues/XX)

**Merged pull requests:**
 - `______` [#XX](https://github.com/UAL-RE/ldcoolp-figshare/pull/XX)

-->
